@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from .user import User
+from archive.user import User
 from rdflib import URIRef
 
 class Guest(User): 
