@@ -9,8 +9,8 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from .node import Node
+from core.graph import Graph
 
-class Model(Node):
-    def __init__(self, id = None, dictionary = None):
-        super().__init__(id, dictionary)
+class Model(Graph):
+    def __init__(self, id:str, triples:set = None):
+        super().__init__(id, triples = triples)
